You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@directory.apache.org by el...@apache.org on 2010/06/15 23:15:06 UTC

svn commit: r955056 [1/5] - in /directory: apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/ apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/event/ apacheds/trunk/core-api/src/main/java/org/apache/directory/...

Author: elecharny
Date: Tue Jun 15 21:15:04 2010
New Revision: 955056

URL: http://svn.apache.org/viewvc?rev=955056&view=rev
Log:
Replace the opContext by its more specific XXXContext name parameter when possible 

Modified:
    directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/OperationManager.java
    directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/event/DirectoryListener.java
    directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/filtering/CursorList.java
    directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/interceptor/BaseInterceptor.java
    directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/interceptor/Interceptor.java
    directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/interceptor/InterceptorChain.java
    directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/interceptor/NextInterceptor.java
    directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/interceptor/context/AbstractOperationContext.java
    directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/partition/NullPartition.java
    directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/partition/Partition.java
    directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/partition/PartitionNexus.java
    directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/SchemaPartition.java
    directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/AbstractRegistrySynchronizer.java
    directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/AttributeTypeSynchronizer.java
    directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/ComparatorSynchronizer.java
    directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/DitContentRuleSynchronizer.java
    directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/DitStructureRuleSynchronizer.java
    directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/MatchingRuleSynchronizer.java
    directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/MatchingRuleUseSynchronizer.java
    directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/NameFormSynchronizer.java
    directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/NormalizerSynchronizer.java
    directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/ObjectClassSynchronizer.java
    directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/RegistrySynchronizer.java
    directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/RegistrySynchronizerAdaptor.java
    directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/SchemaSynchronizer.java
    directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/SyntaxCheckerSynchronizer.java
    directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/SyntaxSynchronizer.java
    directory/apacheds/trunk/core-api/src/test/java/org/apache/directory/server/core/MockCoreSession.java
    directory/apacheds/trunk/core-api/src/test/java/org/apache/directory/server/core/MockInterceptor.java
    directory/apacheds/trunk/core-api/src/test/java/org/apache/directory/server/core/MockOperation.java
    directory/apacheds/trunk/core-api/src/test/java/org/apache/directory/server/core/MockOperationManager.java
    directory/apacheds/trunk/core-integ/src/test/java/org/apache/directory/server/core/operations/getRootDse/GetRootDsePerfIT.java
    directory/apacheds/trunk/core-integ/src/test/java/org/apache/directory/server/core/operations/hasEntry/hasEntryPerfIT.java
    directory/apacheds/trunk/core-integ/src/test/java/org/apache/directory/server/core/operations/list/ListPerfTest.java
    directory/apacheds/trunk/core-jndi/src/main/java/org/apache/directory/server/core/jndi/EventListenerAdapter.java
    directory/apacheds/trunk/core-jndi/src/main/java/org/apache/directory/server/core/jndi/ServerContext.java
    directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/DefaultCoreSession.java
    directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/DefaultOperationManager.java
    directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/authn/AnonymousAuthenticator.java
    directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/authn/AuthenticationInterceptor.java
    directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/authn/Authenticator.java
    directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/authn/SimpleAuthenticator.java
    directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/authn/StrongAuthenticator.java
    directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/authz/AciAuthorizationInterceptor.java
    directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/authz/DefaultAuthorizationInterceptor.java
    directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/changelog/ChangeLogInterceptor.java
    directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/collective/CollectiveAttributeInterceptor.java
    directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/collective/CollectiveAttributesSchemaChecker.java
    directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/event/EventInterceptor.java
    directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/exception/ExceptionInterceptor.java
    directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/journal/JournalInterceptor.java
    directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/logger/TimerInterceptor.java
    directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/normalization/NormalizationInterceptor.java
    directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/operational/OperationalAttributeInterceptor.java
    directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/partition/DefaultPartitionNexus.java
    directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/referral/ReferralInterceptor.java
    directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/schema/SchemaInterceptor.java
    directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/schema/SchemaSubentryManager.java
    directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/subtree/SubentryInterceptor.java
    directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/trigger/TriggerInterceptor.java
    directory/apacheds/trunk/core/src/test/java/org/apache/directory/server/core/interceptor/InterceptorChainTest.java
    directory/apacheds/trunk/ldap-client-test/src/test/java/org/apache/directory/shared/client/api/operations/bind/SimpleBindRequestTest.java
    directory/apacheds/trunk/protocol-ldap/src/main/java/org/apache/directory/server/ldap/handlers/BindHandler.java
    directory/apacheds/trunk/protocol-ldap/src/main/java/org/apache/directory/server/ldap/handlers/PersistentSearchListener.java
    directory/apacheds/trunk/protocol-ldap/src/main/java/org/apache/directory/server/ldap/handlers/bind/SimpleMechanismHandler.java
    directory/apacheds/trunk/protocol-ldap/src/main/java/org/apache/directory/server/ldap/replication/SyncReplSearchListener.java
    directory/apacheds/trunk/server-integ/src/test/java/org/apache/directory/server/operations/search/SearchLimitsIT.java
    directory/apacheds/trunk/xdbm-partition/src/main/java/org/apache/directory/server/core/partition/impl/btree/BTreePartition.java
    directory/installers/trunk/apacheds-noarch/src/main/java/org/apache/directory/server/Service.java

Modified: directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/OperationManager.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/OperationManager.java?rev=955056&r1=955055&r2=955056&view=diff
==============================================================================
--- directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/OperationManager.java (original)
+++ directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/OperationManager.java Tue Jun 15 21:15:04 2010
@@ -50,83 +50,83 @@ public interface OperationManager
     /**
      * TODO document after determining if this method should be here.
      */
-    Entry getRootDSE( GetRootDSEOperationContext  opContext ) throws LdapException;
+    Entry getRootDSE( GetRootDSEOperationContext  getRootDseContext ) throws LdapException;
 
 
     /**
      * TODO document after determining if this method should be here.
      */
-    boolean compare( CompareOperationContext opContext) throws LdapException;
+    boolean compare( CompareOperationContext compareContext) throws LdapException;
 
 
     /**
      * TODO document after determining if this method should be here.
      */
-    void delete( DeleteOperationContext opContext ) throws LdapException;
+    void delete( DeleteOperationContext deleteContext ) throws LdapException;
 
 
     /**
      * TODO document after determining if this method should be here.
      */
-    void add( AddOperationContext opContext ) throws LdapException;
+    void add( AddOperationContext addContext ) throws LdapException;
 
 
     /**
      * TODO document after determining if this method should be here.
      */
-    void modify( ModifyOperationContext opContext ) throws LdapException;
+    void modify( ModifyOperationContext modifyContext ) throws LdapException;
 
 
     /**
      * TODO document after determining if this method should be here.
      */
-    EntryFilteringCursor list( ListOperationContext opContext ) throws LdapException;
+    EntryFilteringCursor list( ListOperationContext listContext ) throws LdapException;
 
 
     /**
      * TODO document after determining if this method should be here.
      */
-    EntryFilteringCursor search( SearchOperationContext opContext ) throws LdapException;
+    EntryFilteringCursor search( SearchOperationContext searchContext ) throws LdapException;
 
 
     /**
      * TODO document after determining if this method should be here.
      */
-    Entry lookup( LookupOperationContext opContext ) throws LdapException;
+    Entry lookup( LookupOperationContext lookupContext ) throws LdapException;
 
 
     /**
      * TODO document after determining if this method should be here.
      */
-    boolean hasEntry( EntryOperationContext opContext ) throws LdapException;
+    boolean hasEntry( EntryOperationContext hasEntryContext ) throws LdapException;
 
 
     /**
      * TODO document after determining if this method should be here.
      */
-    void rename( RenameOperationContext opContext ) throws LdapException;
+    void rename( RenameOperationContext renameContext ) throws LdapException;
 
 
     /**
      * TODO document after determining if this method should be here.
      */
-    void move( MoveOperationContext opContext ) throws LdapException;
+    void move( MoveOperationContext moveContext ) throws LdapException;
 
 
     /**
      * TODO document after determining if this method should be here.
      */
-    void moveAndRename( MoveAndRenameOperationContext opContext ) throws LdapException;
+    void moveAndRename( MoveAndRenameOperationContext moveAndRenameContext ) throws LdapException;
 
     
     /**
      * TODO document after determining if this method should be here.
      */
-    void bind( BindOperationContext opContext ) throws LdapException;
+    void bind( BindOperationContext bindContext ) throws LdapException;
 
     
     /**
      * TODO document after determining if this method should be here.
      */
-    void unbind( UnbindOperationContext opContext ) throws LdapException;
+    void unbind( UnbindOperationContext unbindContext ) throws LdapException;
 }

Modified: directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/event/DirectoryListener.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/event/DirectoryListener.java?rev=955056&r1=955055&r2=955056&view=diff
==============================================================================
--- directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/filtering/CursorList.java (original)
+++ directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/filtering/CursorList.java Tue Jun 15 21:15:04 2010
@@ -60,7 +60,7 @@ public class CursorList implements Entry
     private int index = -1;
 
     /** the operation context */
-    private SearchingOperationContext opContext;
+    private SearchingOperationContext searchContext;
 
     /** flag to detect the closed cursor */
     private boolean closed;
@@ -80,7 +80,7 @@ public class CursorList implements Entry
      * @param list the list this ListCursor operates on
      * @param end the upper bound index
      */
-    public CursorList( int start, List<EntryFilteringCursor> list, int end, SearchingOperationContext opContext )
+    public CursorList( int start, List<EntryFilteringCursor> list, int end, SearchingOperationContext searchContext )
     {
         if ( list != null )
         {
@@ -110,7 +110,7 @@ public class CursorList implements Entry
 
         this.start = start;
         this.end = end;
-        this.opContext = opContext;
+        this.searchContext = searchContext;
     }
 
 
@@ -120,9 +120,9 @@ public class CursorList implements Entry
      *
      * @param list the backing for this ListCursor
      */
-    public CursorList( List<EntryFilteringCursor> list, SearchingOperationContext opContext )
+    public CursorList( List<EntryFilteringCursor> list, SearchingOperationContext searchContext )
     {
-        this( 0, list, list.size(), opContext );
+        this( 0, list, list.size(), searchContext );
     }
 
 
@@ -409,7 +409,7 @@ public class CursorList implements Entry
 
     public SearchingOperationContext getOperationContext()
     {
-        return opContext;
+        return searchContext;
     }
 
 

Modified: directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/interceptor/BaseInterceptor.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/interceptor/BaseInterceptor.java?rev=955056&r1=955055&r2=955056&view=diff
==============================================================================
--- directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/interceptor/BaseInterceptor.java (original)
+++ directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/interceptor/BaseInterceptor.java Tue Jun 15 21:15:04 2010
@@ -121,39 +121,39 @@ public abstract class BaseInterceptor im
     }
 
 
-    public void delete( NextInterceptor next, DeleteOperationContext opContext ) throws LdapException
+    public void delete( NextInterceptor next, DeleteOperationContext deleteContext ) throws LdapException
     {
-        next.delete( opContext );
+        next.delete( deleteContext );
     }
 
 
-    public Entry getRootDSE( NextInterceptor next, GetRootDSEOperationContext opContext ) throws LdapException
+    public Entry getRootDSE( NextInterceptor next, GetRootDSEOperationContext getRootDseContext ) throws LdapException
     {
-        return next.getRootDSE( opContext );
+        return next.getRootDSE( getRootDseContext );
     }
 
 
-    public boolean hasEntry( NextInterceptor next, EntryOperationContext opContext ) throws LdapException
+    public boolean hasEntry( NextInterceptor next, EntryOperationContext hasEntryContext ) throws LdapException
     {
-        return next.hasEntry( opContext );
+        return next.hasEntry( hasEntryContext );
     }
 
 
-    public EntryFilteringCursor list( NextInterceptor next, ListOperationContext opContext ) throws LdapException
+    public EntryFilteringCursor list( NextInterceptor next, ListOperationContext listContext ) throws LdapException
     {
-        return next.list( opContext );
+        return next.list( listContext );
     }
 
 
-    public Entry lookup( NextInterceptor next, LookupOperationContext opContext ) throws LdapException
+    public Entry lookup( NextInterceptor next, LookupOperationContext lookupContext ) throws LdapException
     {
-        return next.lookup( opContext );
+        return next.lookup( lookupContext );
     }
 
     
-    public void modify( NextInterceptor next, ModifyOperationContext opContext ) throws LdapException
+    public void modify( NextInterceptor next, ModifyOperationContext modifyContext ) throws LdapException
     {
-        next.modify( opContext );
+        next.modify( modifyContext );
     }
 
 
@@ -164,10 +164,10 @@ public abstract class BaseInterceptor im
     }
 
 
-    public void rename( NextInterceptor next, RenameOperationContext opContext )
+    public void rename( NextInterceptor next, RenameOperationContext renameContext )
         throws LdapException
     {
-        next.rename( opContext );
+        next.rename( renameContext );
     }
 
 
@@ -180,9 +180,9 @@ public abstract class BaseInterceptor im
     }
 
 
-    public EntryFilteringCursor search( NextInterceptor next, SearchOperationContext opContext ) throws LdapException
+    public EntryFilteringCursor search( NextInterceptor next, SearchOperationContext searchContext ) throws LdapException
     {
-        return next.search( opContext );
+        return next.search( searchContext );
     }
 
 
@@ -192,14 +192,14 @@ public abstract class BaseInterceptor im
     }
 
 
-    public void bind( NextInterceptor next, BindOperationContext opContext ) throws LdapException
+    public void bind( NextInterceptor next, BindOperationContext bindContext ) throws LdapException
     {
-        next.bind( opContext );
+        next.bind( bindContext );
     }
 
 
-    public void unbind( NextInterceptor next, UnbindOperationContext opContext ) throws LdapException
+    public void unbind( NextInterceptor next, UnbindOperationContext unbindContext ) throws LdapException
     {
-        next.unbind( opContext );
+        next.unbind( unbindContext );
     }
 }

Modified: directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/interceptor/Interceptor.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/interceptor/Interceptor.java?rev=955056&r1=955055&r2=955056&view=diff
==============================================================================
--- directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/interceptor/Interceptor.java (original)
+++ directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/interceptor/Interceptor.java Tue Jun 15 21:15:04 2010
@@ -128,7 +128,7 @@ public interface Interceptor
     /**
      * Filters {@link DefaultPartitionNexus#getRootDSE( GetRootDSEOperationContext )} call.
      */
-    Entry getRootDSE( NextInterceptor next, GetRootDSEOperationContext  opContext ) throws LdapException;
+    Entry getRootDSE( NextInterceptor next, GetRootDSEOperationContext  getRootDseContext ) throws LdapException;
 
 
     /**
@@ -140,7 +140,7 @@ public interface Interceptor
     /**
      * Filters {@link Partition#delete( DeleteOperationContext )} call.
      */
-    void delete( NextInterceptor next, DeleteOperationContext opContext ) throws LdapException;
+    void delete( NextInterceptor next, DeleteOperationContext deleteContext ) throws LdapException;
 
 
     /**
@@ -152,43 +152,43 @@ public interface Interceptor
     /**
      * Filters {@link Partition#modify( ModifyOperationContext )} call.
      */
-    void modify( NextInterceptor next, ModifyOperationContext opContext ) throws LdapException;
+    void modify( NextInterceptor next, ModifyOperationContext modifyContext ) throws LdapException;
 
 
     /**
      * Filters {@link Partition#list( ListOperationContext )} call.
      */
-    EntryFilteringCursor list( NextInterceptor next, ListOperationContext opContext ) throws LdapException;
+    EntryFilteringCursor list( NextInterceptor next, ListOperationContext listContext ) throws LdapException;
 
 
     /**
      * Filters {@link Partition#search( SearchOperationContext )} call.
      */
-    EntryFilteringCursor search( NextInterceptor next, SearchOperationContext opContext ) throws LdapException;
+    EntryFilteringCursor search( NextInterceptor next, SearchOperationContext searchContext ) throws LdapException;
 
 
     /**
      * Filters {@link Partition#lookup( LookupOperationContext )} call.
      */
-    Entry lookup( NextInterceptor next, LookupOperationContext opContext ) throws LdapException;
+    Entry lookup( NextInterceptor next, LookupOperationContext lookupContext ) throws LdapException;
 
 
     /**
      * Filters {@link Partition#hasEntry( EntryOperationContext )} call.
      */
-    boolean hasEntry( NextInterceptor next, EntryOperationContext opContext ) throws LdapException;
+    boolean hasEntry( NextInterceptor next, EntryOperationContext hasEntryContext ) throws LdapException;
 
 
     /**
      * Filters {@link Partition#rename( RenameOperationContext )} call.
      */
-    void rename( NextInterceptor next, RenameOperationContext opContext ) throws LdapException;
+    void rename( NextInterceptor next, RenameOperationContext renameContext ) throws LdapException;
 
 
     /**
      * Filters {@link Partition#move( MoveOperationContext )} call.
      */
-    void move( NextInterceptor next, MoveOperationContext opContext ) throws LdapException;
+    void move( NextInterceptor next, MoveOperationContext moveContext ) throws LdapException;
 
 
     /**
@@ -200,11 +200,11 @@ public interface Interceptor
     /**
      * Filters {@link Partition#bind( BindOperationContext )} call.
      */
-    void bind( NextInterceptor next, BindOperationContext opContext )
+    void bind( NextInterceptor next, BindOperationContext bindContext )
         throws LdapException;
 
     /**
      * Filters {@link Partition#unbind( UnbindOperationContext )} call.
      */
-    void unbind( NextInterceptor next, UnbindOperationContext opContext ) throws LdapException;
+    void unbind( NextInterceptor next, UnbindOperationContext unbindContext ) throws LdapException;
 }

Modified: directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/interceptor/InterceptorChain.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/interceptor/InterceptorChain.java?rev=955056&r1=955055&r2=955056&view=diff
==============================================================================
--- directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/interceptor/InterceptorChain.java (original)
+++ directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/interceptor/InterceptorChain.java Tue Jun 15 21:15:04 2010
@@ -100,16 +100,16 @@ public class InterceptorChain
         }
 
 
-        public Entry getRootDSE( NextInterceptor next, GetRootDSEOperationContext opContext )
+        public Entry getRootDSE( NextInterceptor next, GetRootDSEOperationContext getRootDseContext )
             throws LdapException
         {
-            return nexus.getRootDSE( opContext );
+            return nexus.getRootDSE( getRootDseContext );
         }
 
 
-        public void delete( NextInterceptor next, DeleteOperationContext opContext ) throws LdapException
+        public void delete( NextInterceptor next, DeleteOperationContext deleteContext ) throws LdapException
         {
-            nexus.delete( opContext );
+            nexus.delete( deleteContext );
         }
 
 
@@ -119,39 +119,39 @@ public class InterceptorChain
         }
 
 
-        public void modify( NextInterceptor next, ModifyOperationContext opContext ) throws LdapException
+        public void modify( NextInterceptor next, ModifyOperationContext modifyContext ) throws LdapException
         {
-            nexus.modify( opContext );
+            nexus.modify( modifyContext );
         }
 
 
-        public EntryFilteringCursor list( NextInterceptor next, ListOperationContext opContext ) throws LdapException
+        public EntryFilteringCursor list( NextInterceptor next, ListOperationContext listContext ) throws LdapException
         {
-            return nexus.list( opContext );
+            return nexus.list( listContext );
         }
 
 
-        public EntryFilteringCursor search( NextInterceptor next, SearchOperationContext opContext ) throws LdapException
+        public EntryFilteringCursor search( NextInterceptor next, SearchOperationContext searchContext ) throws LdapException
         {
-            return nexus.search( opContext );
+            return nexus.search( searchContext );
         }
 
 
-        public ClonedServerEntry lookup( NextInterceptor next, LookupOperationContext opContext ) throws LdapException
+        public ClonedServerEntry lookup( NextInterceptor next, LookupOperationContext lookupContext ) throws LdapException
         {
-            return nexus.lookup( opContext );
+            return nexus.lookup( lookupContext );
         }
 
 
-        public boolean hasEntry( NextInterceptor next, EntryOperationContext opContext ) throws LdapException
+        public boolean hasEntry( NextInterceptor next, EntryOperationContext hasEntryContext ) throws LdapException
         {
-            return nexus.hasEntry( opContext );
+            return nexus.hasEntry( hasEntryContext );
         }
 
 
-        public void rename( NextInterceptor next, RenameOperationContext opContext ) throws LdapException
+        public void rename( NextInterceptor next, RenameOperationContext renameContext ) throws LdapException
         {
-            nexus.rename( opContext );
+            nexus.rename( renameContext );
         }
 
 
@@ -167,15 +167,15 @@ public class InterceptorChain
         }
 
 
-        public void bind( NextInterceptor next, BindOperationContext opContext ) throws LdapException
+        public void bind( NextInterceptor next, BindOperationContext bindContext ) throws LdapException
         {
-            nexus.bind( opContext );
+            nexus.bind( bindContext );
         }
 
 
-        public void unbind( NextInterceptor next, UnbindOperationContext opContext ) throws LdapException
+        public void unbind( NextInterceptor next, UnbindOperationContext unbindContext ) throws LdapException
         {
-            nexus.unbind( opContext );
+            nexus.unbind( unbindContext );
         }
     };
 
@@ -503,7 +503,7 @@ public class InterceptorChain
     }
 
 
-    public Entry getRootDSE( GetRootDSEOperationContext opContext ) throws LdapException
+    public Entry getRootDSE( GetRootDSEOperationContext getRootDseContext ) throws LdapException
     {
         Element entry = getStartingEntry();
         Interceptor head = entry.interceptor;
@@ -511,7 +511,7 @@ public class InterceptorChain
 
         try
         {
-            return head.getRootDSE( next, opContext );
+            return head.getRootDSE( next, getRootDseContext );
         }
         catch ( LdapException le )
         {
@@ -617,16 +617,16 @@ public class InterceptorChain
     }
 
     
-    public void delete( DeleteOperationContext opContext ) throws LdapException
+    public void delete( DeleteOperationContext deleteContext ) throws LdapException
     {
         Element entry = getStartingEntry();
         Interceptor head = entry.interceptor;
         NextInterceptor next = entry.nextInterceptor;
-        eagerlyPopulateFields( opContext );
+        eagerlyPopulateFields( deleteContext );
 
         try
         {
-            head.delete( next, opContext );
+            head.delete( next, deleteContext );
         }
         catch ( LdapException le )
         {
@@ -660,7 +660,7 @@ public class InterceptorChain
     }
 
 
-    public void bind( BindOperationContext opContext ) throws LdapException
+    public void bind( BindOperationContext bindContext ) throws LdapException
     {
         Element node = getStartingEntry();
         Interceptor head = node.interceptor;
@@ -668,7 +668,7 @@ public class InterceptorChain
 
         try
         {
-            head.bind( next, opContext );
+            head.bind( next, bindContext );
         }
         catch ( LdapException le )
         {
@@ -681,7 +681,7 @@ public class InterceptorChain
     }
 
 
-    public void unbind( UnbindOperationContext opContext ) throws LdapException
+    public void unbind( UnbindOperationContext unbindContext ) throws LdapException
     {
         Element node = getStartingEntry();
         Interceptor head = node.interceptor;
@@ -689,7 +689,7 @@ public class InterceptorChain
 
         try
         {
-            head.unbind( next, opContext );
+            head.unbind( next, unbindContext );
         }
         catch ( LdapException le )
         {
@@ -702,16 +702,16 @@ public class InterceptorChain
     }
 
 
-    public void modify( ModifyOperationContext opContext ) throws LdapException
+    public void modify( ModifyOperationContext modifyContext ) throws LdapException
     {
         Element entry = getStartingEntry();
         Interceptor head = entry.interceptor;
         NextInterceptor next = entry.nextInterceptor;
-        eagerlyPopulateFields( opContext );
+        eagerlyPopulateFields( modifyContext );
 
         try
         {
-            head.modify( next, opContext );
+            head.modify( next, modifyContext );
         }
         catch ( LdapException le )
         {
@@ -724,7 +724,7 @@ public class InterceptorChain
     }
 
 
-    public EntryFilteringCursor list( ListOperationContext opContext ) throws LdapException
+    public EntryFilteringCursor list( ListOperationContext listContext ) throws LdapException
     {
         Element entry = getStartingEntry();
         Interceptor head = entry.interceptor;
@@ -732,7 +732,7 @@ public class InterceptorChain
 
         try
         {
-            return head.list( next, opContext );
+            return head.list( next, listContext );
         }
         catch ( LdapException le )
         {
@@ -746,7 +746,7 @@ public class InterceptorChain
     }
 
 
-    public EntryFilteringCursor search( SearchOperationContext opContext ) throws LdapException
+    public EntryFilteringCursor search( SearchOperationContext searchContext ) throws LdapException
     {
         Element entry = getStartingEntry();
         Interceptor head = entry.interceptor;
@@ -754,7 +754,7 @@ public class InterceptorChain
 
         try
         {
-            return head.search( next, opContext );
+            return head.search( next, searchContext );
         }
         catch ( LdapException le )
         {
@@ -768,7 +768,7 @@ public class InterceptorChain
     }
 
 
-    public Entry lookup( LookupOperationContext opContext ) throws LdapException
+    public Entry lookup( LookupOperationContext lookupContext ) throws LdapException
     {
         Element entry = getStartingEntry();
         Interceptor head = entry.interceptor;
@@ -776,7 +776,7 @@ public class InterceptorChain
 
         try
         {
-            return head.lookup( next, opContext );
+            return head.lookup( next, lookupContext );
         }
         catch ( LdapException le )
         {
@@ -790,7 +790,7 @@ public class InterceptorChain
     }
 
 
-    public boolean hasEntry( EntryOperationContext opContext ) throws LdapException
+    public boolean hasEntry( EntryOperationContext hasEntryContext ) throws LdapException
     {
         Element entry = getStartingEntry();
         Interceptor head = entry.interceptor;
@@ -798,7 +798,7 @@ public class InterceptorChain
 
         try
         {
-            return head.hasEntry( next, opContext );
+            return head.hasEntry( next, hasEntryContext );
         }
         catch ( LdapException le )
         {
@@ -924,12 +924,14 @@ public class InterceptorChain
                     }
 
                     OperationContext opContext = InvocationStack.getInstance().peek();
+                    
                     if ( !opContext.hasBypass() )
                     {
                         return Element.this.nextEntry;
                     }
 
                     Element next = Element.this.nextEntry;
+                    
                     while ( next != tail )
                     {
                         if ( opContext.isBypassed( next.getName() ) )
@@ -967,14 +969,14 @@ public class InterceptorChain
                 }
 
 
-                public Entry getRootDSE( GetRootDSEOperationContext opContext ) throws LdapException
+                public Entry getRootDSE( GetRootDSEOperationContext getRootDseContext ) throws LdapException
                 {
                     Element next = getNextEntry();
                     Interceptor interceptor = next.interceptor;
 
                     try
                     {
-                        return interceptor.getRootDSE( next.nextInterceptor, opContext );
+                        return interceptor.getRootDSE( next.nextInterceptor, getRootDseContext );
                     }
                     catch ( LdapException le )
                     {
@@ -988,14 +990,14 @@ public class InterceptorChain
                 }
 
 
-                public void delete( DeleteOperationContext opContext ) throws LdapException
+                public void delete( DeleteOperationContext deleteContext ) throws LdapException
                 {
                     Element next = getNextEntry();
                     Interceptor interceptor = next.interceptor;
 
                     try
                     {
-                        interceptor.delete( next.nextInterceptor, opContext );
+                        interceptor.delete( next.nextInterceptor, deleteContext );
                     }
                     catch ( LdapException le )
                     {
@@ -1028,14 +1030,14 @@ public class InterceptorChain
                 }
 
 
-                public void modify( ModifyOperationContext opContext ) throws LdapException
+                public void modify( ModifyOperationContext modifyContext ) throws LdapException
                 {
                     Element next = getNextEntry();
                     Interceptor interceptor = next.interceptor;
 
                     try
                     {
-                        interceptor.modify( next.nextInterceptor, opContext );
+                        interceptor.modify( next.nextInterceptor, modifyContext );
                     }
                     catch ( LdapException le )
                     {
@@ -1048,14 +1050,14 @@ public class InterceptorChain
                 }
 
 
-                public EntryFilteringCursor list( ListOperationContext opContext ) throws LdapException
+                public EntryFilteringCursor list( ListOperationContext listContext ) throws LdapException
                 {
                     Element next = getNextEntry();
                     Interceptor interceptor = next.interceptor;
 
                     try
                     {
-                        return interceptor.list( next.nextInterceptor, opContext );
+                        return interceptor.list( next.nextInterceptor, listContext );
                     }
                     catch ( LdapException le )
                     {
@@ -1069,14 +1071,14 @@ public class InterceptorChain
                 }
 
 
-                public EntryFilteringCursor search( SearchOperationContext opContext ) throws LdapException
+                public EntryFilteringCursor search( SearchOperationContext searchContext ) throws LdapException
                 {
                     Element next = getNextEntry();
                     Interceptor interceptor = next.interceptor;
 
                     try
                     {
-                        return interceptor.search( next.nextInterceptor, opContext );
+                        return interceptor.search( next.nextInterceptor, searchContext );
                     }
                     catch ( LdapException le )
                     {
@@ -1090,14 +1092,14 @@ public class InterceptorChain
                 }
 
 
-                public Entry lookup( LookupOperationContext opContext ) throws LdapException
+                public Entry lookup( LookupOperationContext lookupContext ) throws LdapException
                 {
                     Element next = getNextEntry();
                     Interceptor interceptor = next.interceptor;
 
                     try
                     {
-                        return interceptor.lookup( next.nextInterceptor, opContext );
+                        return interceptor.lookup( next.nextInterceptor, lookupContext );
                     }
                     catch ( LdapException le )
                     {
@@ -1111,14 +1113,14 @@ public class InterceptorChain
                 }
 
 
-                public boolean hasEntry( EntryOperationContext opContext ) throws LdapException
+                public boolean hasEntry( EntryOperationContext hasEntryContext ) throws LdapException
                 {
                     Element next = getNextEntry();
                     Interceptor interceptor = next.interceptor;
 
                     try
                     {
-                        return interceptor.hasEntry( next.nextInterceptor, opContext );
+                        return interceptor.hasEntry( next.nextInterceptor, hasEntryContext );
                     }
                     catch ( LdapException le )
                     {
@@ -1132,14 +1134,14 @@ public class InterceptorChain
                 }
 
 
-                public void rename( RenameOperationContext opContext ) throws LdapException
+                public void rename( RenameOperationContext renameContext ) throws LdapException
                 {
                     Element next = getNextEntry();
                     Interceptor interceptor = next.interceptor;
 
                     try
                     {
-                        interceptor.rename( next.nextInterceptor, opContext );
+                        interceptor.rename( next.nextInterceptor, renameContext );
                     }
                     catch ( LdapException le )
                     {
@@ -1152,14 +1154,14 @@ public class InterceptorChain
                 }
 
 
-                public void move( MoveOperationContext opContext ) throws LdapException
+                public void move( MoveOperationContext moveContext ) throws LdapException
                 {
                     Element next = getNextEntry();
                     Interceptor interceptor = next.interceptor;
 
                     try
                     {
-                        interceptor.move( next.nextInterceptor, opContext );
+                        interceptor.move( next.nextInterceptor, moveContext );
                     }
                     catch ( LdapException le )
                     {
@@ -1192,14 +1194,14 @@ public class InterceptorChain
                 }
 
 
-                public void bind( BindOperationContext opContext ) throws LdapException
+                public void bind( BindOperationContext bindContext ) throws LdapException
                 {
                     Element next = getNextEntry();
                     Interceptor interceptor = next.interceptor;
 
                     try
                     {
-                        interceptor.bind( next.nextInterceptor, opContext );
+                        interceptor.bind( next.nextInterceptor, bindContext );
                     }
                     catch ( LdapException le )
                     {
@@ -1212,14 +1214,14 @@ public class InterceptorChain
                 }
 
 
-                public void unbind( UnbindOperationContext opContext ) throws LdapException
+                public void unbind( UnbindOperationContext unbindContext ) throws LdapException
                 {
                     Element next = getNextEntry();
                     Interceptor interceptor = next.interceptor;
 
                     try
                     {
-                        interceptor.unbind( next.nextInterceptor, opContext );
+                        interceptor.unbind( next.nextInterceptor, unbindContext );
                     }
                     catch ( LdapException le )
                     {

Modified: directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/interceptor/NextInterceptor.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/interceptor/NextInterceptor.java?rev=955056&r1=955055&r2=955056&view=diff
==============================================================================
--- directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/interceptor/context/AbstractOperationContext.java (original)
+++ directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/interceptor/context/AbstractOperationContext.java Tue Jun 15 21:15:04 2010
@@ -306,65 +306,65 @@ public abstract class AbstractOperationC
     
     public boolean hasEntry( DN dn, Collection<String> byPassed ) throws LdapException
     {
-        EntryOperationContext opContext = new EntryOperationContext( session, dn );
-        setup( opContext );
-        opContext.setByPassed( byPassed );
-        return session.getDirectoryService().getOperationManager().hasEntry( opContext );
+        EntryOperationContext hasEntryContext = new EntryOperationContext( session, dn );
+        setup( hasEntryContext );
+        hasEntryContext.setByPassed( byPassed );
+        return session.getDirectoryService().getOperationManager().hasEntry( hasEntryContext );
     }
     
     
     public void add( Entry entry, Collection<String> byPassed ) throws LdapException
     {
-        AddOperationContext opContext = new AddOperationContext( session, entry );
-        setup( opContext );
-        opContext.setByPassed( byPassed );
-        session.getDirectoryService().getOperationManager().add( opContext );
+        AddOperationContext addContext = new AddOperationContext( session, entry );
+        setup( addContext );
+        addContext.setByPassed( byPassed );
+        session.getDirectoryService().getOperationManager().add( addContext );
     }
     
     
     public void delete( DN dn, Collection<String> byPassed ) throws LdapException
     {
-        DeleteOperationContext opContext = new DeleteOperationContext( session, dn );
-        setup( opContext );
-        opContext.setByPassed( byPassed );
-        session.getDirectoryService().getOperationManager().delete( opContext );
+        DeleteOperationContext deleteContext = new DeleteOperationContext( session, dn );
+        setup( deleteContext );
+        deleteContext.setByPassed( byPassed );
+        session.getDirectoryService().getOperationManager().delete( deleteContext );
     }
     
     
     public void modify( DN dn, List<Modification> mods, Collection<String> byPassed ) throws LdapException
     {
-        ModifyOperationContext opContext = new ModifyOperationContext( session, dn, mods );
-        setup( opContext );
-        opContext.setByPassed( byPassed );
-        session.getDirectoryService().getOperationManager().modify( opContext );
+        ModifyOperationContext modifyContext = new ModifyOperationContext( session, dn, mods );
+        setup( modifyContext );
+        modifyContext.setByPassed( byPassed );
+        session.getDirectoryService().getOperationManager().modify( modifyContext );
     }
     
     
     // TODO - need synchronization here and where we update links
     public LookupOperationContext newLookupContext( DN dn )
     {
-        LookupOperationContext opContext = new LookupOperationContext( session, dn );
-        setup( opContext );
-        return opContext;
+        LookupOperationContext lookupContext = new LookupOperationContext( session, dn );
+        setup( lookupContext );
+        return lookupContext;
     }
 
 
-    public Entry lookup( LookupOperationContext opContext ) throws LdapException
+    public Entry lookup( LookupOperationContext lookupContext ) throws LdapException
     {
-        if ( opContext != next )
+        if ( lookupContext != next )
         {
             throw new IllegalStateException( I18n.err( I18n.ERR_319 ) );
         }
         
-        return session.getDirectoryService().getOperationManager().lookup( opContext );
+        return session.getDirectoryService().getOperationManager().lookup( lookupContext );
     }
 
 
     public Entry lookup( DN dn, Collection<String> byPassed ) throws LdapException
     {
-        LookupOperationContext opContext = newLookupContext( dn );
-        opContext.setByPassed( byPassed );
-        return session.getDirectoryService().getOperationManager().lookup( opContext );
+        LookupOperationContext lookupContext = newLookupContext( dn );
+        lookupContext.setByPassed( byPassed );
+        return session.getDirectoryService().getOperationManager().lookup( lookupContext );
     }
     
 

Modified: directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/partition/NullPartition.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/partition/NullPartition.java?rev=955056&r1=955055&r2=955056&view=diff
==============================================================================
--- directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/partition/NullPartition.java (original)
+++ directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/partition/NullPartition.java Tue Jun 15 21:15:04 2010
@@ -73,7 +73,7 @@ public class NullPartition extends Abstr
     /* (non-Javadoc)
      * @see org.apache.directory.server.core.partition.Partition#add(org.apache.directory.server.core.interceptor.context.AddOperationContext)
      */
-    public void add( AddOperationContext opContext ) throws LdapException
+    public void add( AddOperationContext addContext ) throws LdapException
     {
     }
 
@@ -81,7 +81,7 @@ public class NullPartition extends Abstr
     /* (non-Javadoc)
      * @see org.apache.directory.server.core.partition.Partition#bind(org.apache.directory.server.core.interceptor.context.BindOperationContext)
      */
-    public void bind( BindOperationContext opContext ) throws LdapException
+    public void bind( BindOperationContext bindContext ) throws LdapException
     {
     }
 
@@ -89,7 +89,7 @@ public class NullPartition extends Abstr
     /* (non-Javadoc)
      * @see org.apache.directory.server.core.partition.Partition#delete(org.apache.directory.server.core.interceptor.context.DeleteOperationContext)
      */
-    public void delete( DeleteOperationContext opContext ) throws LdapException
+    public void delete( DeleteOperationContext deleteContext ) throws LdapException
     {
     }
 
@@ -106,7 +106,7 @@ public class NullPartition extends Abstr
     /* (non-Javadoc)
      * @see org.apache.directory.server.core.partition.Partition#list(org.apache.directory.server.core.interceptor.context.ListOperationContext)
      */
-    public EntryFilteringCursor list( ListOperationContext opContext ) throws LdapException
+    public EntryFilteringCursor list( ListOperationContext listContext ) throws LdapException
     {
         return new EntryFilteringCursor()
         {
@@ -289,7 +289,7 @@ public class NullPartition extends Abstr
     /* (non-Javadoc)
      * @see org.apache.directory.server.core.partition.Partition#modify(org.apache.directory.server.core.interceptor.context.ModifyOperationContext)
      */
-    public void modify( ModifyOperationContext opContext ) throws LdapException
+    public void modify( ModifyOperationContext modifyContext ) throws LdapException
     {
     }
 
@@ -297,7 +297,7 @@ public class NullPartition extends Abstr
     /* (non-Javadoc)
      * @see org.apache.directory.server.core.partition.Partition#move(org.apache.directory.server.core.interceptor.context.MoveOperationContext)
      */
-    public void move( MoveOperationContext opContext ) throws LdapException
+    public void move( MoveOperationContext moveContext ) throws LdapException
     {
     }
 
@@ -313,7 +313,7 @@ public class NullPartition extends Abstr
     /* (non-Javadoc)
      * @see org.apache.directory.server.core.partition.Partition#rename(org.apache.directory.server.core.interceptor.context.RenameOperationContext)
      */
-    public void rename( RenameOperationContext opContext ) throws LdapException
+    public void rename( RenameOperationContext renameContext ) throws LdapException
     {
     }
 
@@ -321,7 +321,7 @@ public class NullPartition extends Abstr
     /* (non-Javadoc)
      * @see org.apache.directory.server.core.partition.Partition#search(org.apache.directory.server.core.interceptor.context.SearchOperationContext)
      */
-    public EntryFilteringCursor search( SearchOperationContext opContext ) throws LdapException
+    public EntryFilteringCursor search( SearchOperationContext searchContext ) throws LdapException
     {
         return null;
     }
@@ -348,7 +348,7 @@ public class NullPartition extends Abstr
     /* (non-Javadoc)
      * @see org.apache.directory.server.core.partition.Partition#unbind(org.apache.directory.server.core.interceptor.context.UnbindOperationContext)
      */
-    public void unbind( UnbindOperationContext opContext ) throws LdapException
+    public void unbind( UnbindOperationContext unbindContext ) throws LdapException
     {
     }
 

Modified: directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/partition/Partition.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/partition/Partition.java?rev=955056&r1=955055&r2=955056&view=diff
==============================================================================
--- directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/partition/PartitionNexus.java (original)
+++ directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/partition/PartitionNexus.java Tue Jun 15 21:15:04 2010
@@ -70,7 +70,7 @@ public interface PartitionNexus extends 
     /**
      * Remove a partition from the server.
      * 
-     * @param opContext The Remove Partition context
+     * @param partitionDn the partition DN
      * @throws Exception If the removal can't be done
      */
     public void removeContextPartition( DN partitionDn )
@@ -136,5 +136,5 @@ public interface PartitionNexus extends 
     public void registerSupportedSaslMechanisms( Set<String> supportedSaslMechanisms ) throws LdapException;
 
 
-    public boolean compare( CompareOperationContext opContext ) throws LdapException;
+    public boolean compare( CompareOperationContext compareContext ) throws LdapException;
 }
\ No newline at end of file

Modified: directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/SchemaPartition.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/SchemaPartition.java?rev=955056&r1=955055&r2=955056&view=diff
==============================================================================
--- directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/SchemaPartition.java (original)
+++ directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/SchemaPartition.java Tue Jun 15 21:15:04 2010
@@ -262,17 +262,17 @@ public final class SchemaPartition exten
     /**
      * {@inheritDoc}
      */
-    public void add( AddOperationContext opContext ) throws LdapException
+    public void add( AddOperationContext addContext ) throws LdapException
     {
         // At this point, the added SchemaObject does not exist in the partition
         // We have to check if it's enabled and then inject it into the registries
         // but only if it does not break the server.
-        synchronizer.add( opContext );
+        synchronizer.add( addContext );
 
         // Now, write the newly added SchemaObject into the schemaPartition
         try
         {
-            wrapped.add( opContext );
+            wrapped.add( addContext );
         }
         catch ( LdapException e )
         {
@@ -282,32 +282,32 @@ public final class SchemaPartition exten
             throw e;
         }
 
-        updateSchemaModificationAttributes( opContext );
+        updateSchemaModificationAttributes( addContext );
     }
 
 
     /* (non-Javadoc)
      * @see org.apache.directory.server.core.partition.Partition#bind(org.apache.directory.server.core.interceptor.context.BindOperationContext)
      */
-    public void bind( BindOperationContext opContext ) throws LdapException
+    public void bind( BindOperationContext bindContext ) throws LdapException
     {
-        wrapped.bind( opContext );
+        wrapped.bind( bindContext );
     }
 
 
     /* (non-Javadoc)
      * @see org.apache.directory.server.core.partition.Partition#delete(org.apache.directory.server.core.interceptor.context.DeleteOperationContext)
      */
-    public void delete( DeleteOperationContext opContext ) throws LdapException
+    public void delete( DeleteOperationContext deleteContext ) throws LdapException
     {
-        boolean cascade = opContext.hasRequestControl( CascadeControl.CONTROL_OID );
+        boolean cascade = deleteContext.hasRequestControl( CascadeControl.CONTROL_OID );
 
         // The SchemaObject always exist when we reach this method.
-        synchronizer.delete( opContext, cascade );
+        synchronizer.delete( deleteContext, cascade );
 
         try
         {
-            wrapped.delete( opContext );
+            wrapped.delete( deleteContext );
         }
         catch ( LdapException e )
         {
@@ -315,55 +315,55 @@ public final class SchemaPartition exten
             throw e;
         }
 
-        updateSchemaModificationAttributes( opContext );
+        updateSchemaModificationAttributes( deleteContext );
     }
 
 
     /* (non-Javadoc)
      * @see org.apache.directory.server.core.partition.Partition#list(org.apache.directory.server.core.interceptor.context.ListOperationContext)
      */
-    public EntryFilteringCursor list( ListOperationContext opContext ) throws LdapException
+    public EntryFilteringCursor list( ListOperationContext listContext ) throws LdapException
     {
-        return wrapped.list( opContext );
+        return wrapped.list( listContext );
     }
 
 
     /**
      * {@inheritDoc}
      */
-    public boolean hasEntry( EntryOperationContext entryContext ) throws LdapException
+    public boolean hasEntry( EntryOperationContext hasEntryContext ) throws LdapException
     {
-        return wrapped.hasEntry( entryContext );
+        return wrapped.hasEntry( hasEntryContext );
     }
 
 
     /**
      * {@inheritDoc}
      */
-    public void modify( ModifyOperationContext opContext ) throws LdapException
+    public void modify( ModifyOperationContext modifyContext ) throws LdapException
     {
-        Entry entry = opContext.getEntry();
+        Entry entry = modifyContext.getEntry();
 
         if ( entry == null )
         {
-            LookupOperationContext lookupCtx = new LookupOperationContext( opContext.getSession(), opContext.getDn() );
+            LookupOperationContext lookupCtx = new LookupOperationContext( modifyContext.getSession(), modifyContext.getDn() );
             entry = wrapped.lookup( lookupCtx );
         }
 
-        Entry targetEntry = ( Entry ) SchemaUtils.getTargetEntry( opContext.getModItems(), entry );
+        Entry targetEntry = ( Entry ) SchemaUtils.getTargetEntry( modifyContext.getModItems(), entry );
 
-        boolean cascade = opContext.hasRequestControl( CascadeControl.CONTROL_OID );
+        boolean cascade = modifyContext.hasRequestControl( CascadeControl.CONTROL_OID );
 
-        boolean hasModification = synchronizer.modify( opContext, targetEntry, cascade );
+        boolean hasModification = synchronizer.modify( modifyContext, targetEntry, cascade );
 
         if ( hasModification )
         {
-            wrapped.modify( opContext );
+            wrapped.modify( modifyContext );
         }
 
-        if ( !opContext.getDn().equals( schemaModificationDN ) )
+        if ( !modifyContext.getDn().equals( schemaModificationDN ) )
         {
-            updateSchemaModificationAttributes( opContext );
+            updateSchemaModificationAttributes( modifyContext );
         }
     }
 
@@ -371,13 +371,13 @@ public final class SchemaPartition exten
     /* (non-Javadoc)
      * @see org.apache.directory.server.core.partition.Partition#move(org.apache.directory.server.core.interceptor.context.MoveOperationContext)
      */
-    public void move( MoveOperationContext opContext ) throws LdapException
+    public void move( MoveOperationContext moveContext ) throws LdapException
     {
-        boolean cascade = opContext.hasRequestControl( CascadeControl.CONTROL_OID );
-        Entry entry = opContext.lookup( opContext.getDn(), ByPassConstants.LOOKUP_BYPASS );
-        synchronizer.move( opContext, entry, cascade );
-        wrapped.move( opContext );
-        updateSchemaModificationAttributes( opContext );
+        boolean cascade = moveContext.hasRequestControl( CascadeControl.CONTROL_OID );
+        Entry entry = moveContext.lookup( moveContext.getDn(), ByPassConstants.LOOKUP_BYPASS );
+        synchronizer.move( moveContext, entry, cascade );
+        wrapped.move( moveContext );
+        updateSchemaModificationAttributes( moveContext );
     }
 
 
@@ -397,36 +397,36 @@ public final class SchemaPartition exten
     /**
      * {@inheritDoc}
      */
-    public void rename( RenameOperationContext opContext ) throws LdapException
+    public void rename( RenameOperationContext renameContext ) throws LdapException
     {
-        boolean cascade = opContext.hasRequestControl( CascadeControl.CONTROL_OID );
+        boolean cascade = renameContext.hasRequestControl( CascadeControl.CONTROL_OID );
 
         // First update the registries
-        synchronizer.rename( opContext, cascade );
+        synchronizer.rename( renameContext, cascade );
 
         // Update the schema partition
-        wrapped.rename( opContext );
+        wrapped.rename( renameContext );
 
         // Update the SSSE operational attributes
-        updateSchemaModificationAttributes( opContext );
+        updateSchemaModificationAttributes( renameContext );
     }
 
 
     /* (non-Javadoc)
      * @see org.apache.directory.server.core.partition.Partition#search(org.apache.directory.server.core.interceptor.context.SearchOperationContext)
      */
-    public EntryFilteringCursor search( SearchOperationContext opContext ) throws LdapException
+    public EntryFilteringCursor search( SearchOperationContext searchContext ) throws LdapException
     {
-        return wrapped.search( opContext );
+        return wrapped.search( searchContext );
     }
 
 
     /* (non-Javadoc)
      * @see org.apache.directory.server.core.partition.Partition#unbind(org.apache.directory.server.core.interceptor.context.UnbindOperationContext)
      */
-    public void unbind( UnbindOperationContext opContext ) throws LdapException
+    public void unbind( UnbindOperationContext unbindContext ) throws LdapException
     {
-        wrapped.unbind( opContext );
+        wrapped.unbind( unbindContext );
     }
 
 

Modified: directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/AbstractRegistrySynchronizer.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/AbstractRegistrySynchronizer.java?rev=955056&r1=955055&r2=955056&view=diff
==============================================================================
--- directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/AbstractRegistrySynchronizer.java (original)
+++ directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/AbstractRegistrySynchronizer.java Tue Jun 15 21:15:04 2010
@@ -317,7 +317,7 @@ public abstract class AbstractRegistrySy
     /**
      * {@inheritDoc}
      */
-    public abstract boolean modify( ModifyOperationContext opContext, Entry targetEntry, boolean cascade ) 
+    public abstract boolean modify( ModifyOperationContext modifyContext, Entry targetEntry, boolean cascade ) 
         throws LdapException;
     
     

Modified: directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/AttributeTypeSynchronizer.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/AttributeTypeSynchronizer.java?rev=955056&r1=955055&r2=955056&view=diff
==============================================================================
--- directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/AttributeTypeSynchronizer.java (original)
+++ directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/AttributeTypeSynchronizer.java Tue Jun 15 21:15:04 2010
@@ -112,11 +112,11 @@ public class AttributeTypeSynchronizer e
     /**
      * {@inheritDoc}
      */
-    public boolean modify( ModifyOperationContext opContext, Entry targetEntry, boolean cascade )
+    public boolean modify( ModifyOperationContext modifyContext, Entry targetEntry, boolean cascade )
         throws LdapException
     {
-        DN name = opContext.getDn();
-        Entry entry = opContext.getEntry();
+        DN name = modifyContext.getDn();
+        Entry entry = modifyContext.getEntry();
         String schemaName = getSchemaName( name );
         String oid = getOid( entry );
         AttributeType at = factory.getAttributeType( schemaManager, targetEntry, schemaManager.getRegistries(),

Modified: directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/ComparatorSynchronizer.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/ComparatorSynchronizer.java?rev=955056&r1=955055&r2=955056&view=diff
==============================================================================
--- directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/ComparatorSynchronizer.java (original)
+++ directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/ComparatorSynchronizer.java Tue Jun 15 21:15:04 2010
@@ -70,11 +70,11 @@ public class ComparatorSynchronizer exte
     /**
      * {@inheritDoc}
      */
-    public boolean modify( ModifyOperationContext opContext, Entry targetEntry, boolean cascade )
+    public boolean modify( ModifyOperationContext modifyContext, Entry targetEntry, boolean cascade )
         throws LdapException
     {
-        DN name = opContext.getDn();
-        Entry entry = opContext.getEntry();
+        DN name = modifyContext.getDn();
+        Entry entry = modifyContext.getEntry();
         String schemaName = getSchemaName( name );
         String oid = getOid( entry );
         LdapComparator<?> comparator = factory.getLdapComparator( schemaManager, targetEntry, schemaManager

Modified: directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/DitContentRuleSynchronizer.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/DitContentRuleSynchronizer.java?rev=955056&r1=955055&r2=955056&view=diff
==============================================================================
--- directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/DitContentRuleSynchronizer.java (original)
+++ directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/DitContentRuleSynchronizer.java Tue Jun 15 21:15:04 2010
@@ -54,7 +54,7 @@ public class DitContentRuleSynchronizer 
      * {@inheritDoc}
      */
     @Override
-    public boolean modify( ModifyOperationContext opContext, Entry targetEntry, boolean cascade ) 
+    public boolean modify( ModifyOperationContext modifyContext, Entry targetEntry, boolean cascade ) 
         throws LdapException
     {
         // TODO Auto-generated method stub

Modified: directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/DitStructureRuleSynchronizer.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/DitStructureRuleSynchronizer.java?rev=955056&r1=955055&r2=955056&view=diff
==============================================================================
--- directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/DitStructureRuleSynchronizer.java (original)
+++ directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/DitStructureRuleSynchronizer.java Tue Jun 15 21:15:04 2010
@@ -53,7 +53,7 @@ public class DitStructureRuleSynchronize
      * {@inheritDoc}
      */
     @Override
-    public boolean modify( ModifyOperationContext opContext, Entry targetEntry, 
+    public boolean modify( ModifyOperationContext modifyContext, Entry targetEntry, 
         boolean cascade ) throws LdapException
     {
         // TODO Auto-generated method stub

Modified: directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/MatchingRuleSynchronizer.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/MatchingRuleSynchronizer.java?rev=955056&r1=955055&r2=955056&view=diff
==============================================================================
--- directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/MatchingRuleSynchronizer.java (original)
+++ directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/MatchingRuleSynchronizer.java Tue Jun 15 21:15:04 2010
@@ -66,11 +66,11 @@ public class MatchingRuleSynchronizer ex
     /**
      * {@inheritDoc}
      */
-    public boolean modify( ModifyOperationContext opContext, Entry targetEntry, boolean cascade )
+    public boolean modify( ModifyOperationContext modifyContext, Entry targetEntry, boolean cascade )
         throws LdapException
     {
-        DN name = opContext.getDn();
-        Entry entry = opContext.getEntry();
+        DN name = modifyContext.getDn();
+        Entry entry = modifyContext.getEntry();
         String schemaName = getSchemaName( name );
         MatchingRule mr = factory.getMatchingRule( schemaManager, targetEntry, schemaManager.getRegistries(),
             schemaName );

Modified: directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/MatchingRuleUseSynchronizer.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/MatchingRuleUseSynchronizer.java?rev=955056&r1=955055&r2=955056&view=diff
==============================================================================
--- directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/MatchingRuleUseSynchronizer.java (original)
+++ directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/MatchingRuleUseSynchronizer.java Tue Jun 15 21:15:04 2010
@@ -53,7 +53,7 @@ public class MatchingRuleUseSynchronizer
      * {@inheritDoc}
      */
     @Override
-    public boolean modify( ModifyOperationContext opContext, Entry targetEntry, 
+    public boolean modify( ModifyOperationContext modifyContext, Entry targetEntry, 
         boolean cascade ) throws LdapException
     {
         // TODO Auto-generated method stub

Modified: directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/NameFormSynchronizer.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/NameFormSynchronizer.java?rev=955056&r1=955055&r2=955056&view=diff
==============================================================================
--- directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/NameFormSynchronizer.java (original)
+++ directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/NameFormSynchronizer.java Tue Jun 15 21:15:04 2010
@@ -52,7 +52,7 @@ public class NameFormSynchronizer extend
      * {@inheritDoc}
      */
     @Override
-    public boolean modify( ModifyOperationContext opContext, Entry targetEntry, 
+    public boolean modify( ModifyOperationContext modifyContext, Entry targetEntry, 
         boolean cascade ) throws LdapException
     {
         return SCHEMA_UNCHANGED;

Modified: directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/NormalizerSynchronizer.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/NormalizerSynchronizer.java?rev=955056&r1=955055&r2=955056&view=diff
==============================================================================
--- directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/NormalizerSynchronizer.java (original)
+++ directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/NormalizerSynchronizer.java Tue Jun 15 21:15:04 2010
@@ -69,11 +69,11 @@ public class NormalizerSynchronizer exte
     /**
      * {@inheritDoc}
      */
-    public boolean modify( ModifyOperationContext opContext, Entry targetEntry, boolean cascade )
+    public boolean modify( ModifyOperationContext modifyContext, Entry targetEntry, boolean cascade )
         throws LdapException
     {
-        DN name = opContext.getDn();
-        Entry entry = opContext.getEntry();
+        DN name = modifyContext.getDn();
+        Entry entry = modifyContext.getEntry();
         String schemaName = getSchemaName( name );
         String oldOid = getOid( entry );
         Normalizer normalizer = factory.getNormalizer( schemaManager, targetEntry, schemaManager.getRegistries(),

Modified: directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/ObjectClassSynchronizer.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/ObjectClassSynchronizer.java?rev=955056&r1=955055&r2=955056&view=diff
==============================================================================
--- directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/ObjectClassSynchronizer.java (original)
+++ directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/ObjectClassSynchronizer.java Tue Jun 15 21:15:04 2010
@@ -65,11 +65,11 @@ public class ObjectClassSynchronizer ext
     /**
      * {@inheritDoc}
      */
-    public boolean modify( ModifyOperationContext opContext, Entry targetEntry, boolean cascade )
+    public boolean modify( ModifyOperationContext modifyContext, Entry targetEntry, boolean cascade )
         throws LdapException
     {
-        DN name = opContext.getDn();
-        Entry entry = opContext.getEntry();
+        DN name = modifyContext.getDn();
+        Entry entry = modifyContext.getEntry();
         String oid = getOid( entry );
         ObjectClass oc = factory.getObjectClass( schemaManager, targetEntry, schemaManager.getRegistries(),
             getSchemaName( name ) );

Modified: directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/RegistrySynchronizer.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/RegistrySynchronizer.java?rev=955056&r1=955055&r2=955056&view=diff
==============================================================================
--- directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/event/DirectoryListener.java (original)
+++ directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/event/DirectoryListener.java Tue Jun 15 21:15:04 2010
@@ -38,47 +38,47 @@ public interface DirectoryListener
     /**
      * Called when an entry has been added.
      *
      * @param opContext the add operation context responsible for the change
      */
-    void entryAdded( AddOperationContext opContext ); 
+    void entryAdded( AddOperationContext addContext ); 
     
     
     /**
      * Called when an entry has been deleted.
      *
      * @param opContext the delete operation context responsible for the change
      */
-    void entryDeleted( DeleteOperationContext opContext );
+    void entryDeleted( DeleteOperationContext deleteContext );
     
     
     /**
      * Called when an entry has been modified.
      *
      * @param opContext the modify operation context responsible for the change
      */
-    void entryModified( ModifyOperationContext opContext );
+    void entryModified( ModifyOperationContext modifyContext );
     
     
     /**
      * Called when an entry has been renamed.
      *
      * @param opContext the rename operation context responsible for the change
      */
-    void entryRenamed( RenameOperationContext opContext );
+    void entryRenamed( RenameOperationContext renameContext );
     
     
     /**
      * Called when an entry is moved.
      *
      * @param opContext the move operation context responsible for the change
      */
-    void entryMoved( MoveOperationContext opContext );
+    void entryMoved( MoveOperationContext moveContext );
     
     
     /**
      * Called when an entry is moved and renamed at the same time.
      *
      * @param opContext the move/rename operation context responsible for the change
      */
-    void entryMovedAndRenamed( MoveAndRenameOperationContext opContext );
+    void entryMovedAndRenamed( MoveAndRenameOperationContext moveAndRenameContext );
 }
@@ -38,47 +38,47 @@ public interface DirectoryListener
      * Called when an entry has been added.
      *
-     * @param opContext the add operation context responsible for the change
+     * @param addContext the add operation context responsible for the change
      */
@@ -38,47 +38,47 @@ public interface DirectoryListener
      * Called when an entry has been deleted.
      *
-     * @param opContext the delete operation context responsible for the change
+     * @param deleteContext the delete operation context responsible for the change
      */
@@ -38,47 +38,47 @@ public interface DirectoryListener
      * Called when an entry has been modified.
      *
-     * @param opContext the modify operation context responsible for the change
+     * @param modifyContext the modify operation context responsible for the change
      */
@@ -38,47 +38,47 @@ public interface DirectoryListener
      * Called when an entry has been renamed.
      *
-     * @param opContext the rename operation context responsible for the change
+     * @param renameContext the rename operation context responsible for the change
      */
@@ -38,47 +38,47 @@ public interface DirectoryListener
      * Called when an entry is moved.
      *
-     * @param opContext the move operation context responsible for the change
+     * @param moveContext the move operation context responsible for the change
      */
@@ -38,47 +38,47 @@ public interface DirectoryListener
      * Called when an entry is moved and renamed at the same time.
      *
-     * @param opContext the move/rename operation context responsible for the change
+     * @param moveAndRenameContext the move/rename operation context responsible for the change
      */

Modified: directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/filtering/CursorList.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/filtering/CursorList.java?rev=955056&r1=955055&r2=955056&view=diff
==============================================================================
--- directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/interceptor/NextInterceptor.java (original)
+++ directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/interceptor/NextInterceptor.java Tue Jun 15 21:15:04 2010
@@ -57,13 +57,13 @@ public interface NextInterceptor
     /**
      * Calls the next interceptor's {@link Interceptor#getRootDSE( NextInterceptor, GetRootDSEOperationContext )}.
      */
-    Entry getRootDSE( GetRootDSEOperationContext opContext ) throws LdapException;
+    Entry getRootDSE( GetRootDSEOperationContext getRootDseContext ) throws LdapException;
 
 
     /**
      * Calls the next interceptor's {@link Interceptor#delete(NextInterceptor, DeleteOperationContext )}.
      */
-    void delete( DeleteOperationContext opContext ) throws LdapException;
+    void delete( DeleteOperationContext deleteContext ) throws LdapException;
 
 
     /**
@@ -75,42 +75,42 @@ public interface NextInterceptor
     /**
      * Calls the next interceptor's {@link Interceptor#modify( NextInterceptor, ModifyOperationContext )}.
      */
-    void modify( ModifyOperationContext opContext ) throws LdapException;
+    void modify( ModifyOperationContext modifyContext ) throws LdapException;
 
     /**
      * Calls the next interceptor's {@link Interceptor#list( NextInterceptor, ListOperationContext )}.
      */
-    EntryFilteringCursor list( ListOperationContext opContext ) throws LdapException;
+    EntryFilteringCursor list( ListOperationContext listContext ) throws LdapException;
 
 
     /**
      * Calls the next interceptor's {@link Interceptor#search( NextInterceptor, SearchOperationContext opContext )}.
      */
-    EntryFilteringCursor search( SearchOperationContext opContext ) throws LdapException;
+    EntryFilteringCursor search( SearchOperationContext searchContext ) throws LdapException;
 
 
     /**
      * Calls the next interceptor's {@link Interceptor#lookup( NextInterceptor, LookupOperationContext )}.
      */
-    Entry lookup( LookupOperationContext opContext ) throws LdapException;
+    Entry lookup( LookupOperationContext lookupContext ) throws LdapException;
 
 
     /**
      * Calls the next interceptor's {@link Interceptor#hasEntry( NextInterceptor, EntryOperationContext )}.
      */
-    boolean hasEntry( EntryOperationContext opContext ) throws LdapException;
+    boolean hasEntry( EntryOperationContext hasEntryContext ) throws LdapException;
 
 
     /**
      * Calls the next interceptor's {@link Interceptor#rename( NextInterceptor, RenameOperationContext )}.
      */
-    void rename( RenameOperationContext opContext ) throws LdapException;
+    void rename( RenameOperationContext renameContext ) throws LdapException;
 
 
     /**
      * Calls the next interceptor's {@link Interceptor#move( NextInterceptor, MoveOperationContext )}.
      */
-    void move( MoveOperationContext opContext ) throws LdapException;
+    void move( MoveOperationContext moveContext ) throws LdapException;
 
 
     /**
@@ -122,10 +122,10 @@ public interface NextInterceptor
     /**
      * Calls the next interceptor's {@link Interceptor#bind( NextInterceptor, BindOperationContext )}
      */
-    void bind( BindOperationContext opContext ) throws LdapException;
+    void bind( BindOperationContext bindContext ) throws LdapException;
 
     /**
      * Calls the next interceptor's {@link Interceptor#unbind( NextInterceptor, UnbindOperationContext )}
      */
-    void unbind( UnbindOperationContext opContext ) throws LdapException;
+    void unbind( UnbindOperationContext unbindContext ) throws LdapException;
 }
@@ -75,42 +75,42 @@ public interface NextInterceptor
 
     /**
-     * Calls the next interceptor's {@link Interceptor#search( NextInterceptor, SearchOperationContext opContext )}.
+     * Calls the next interceptor's {@link Interceptor#search( NextInterceptor, SearchOperationContext searchContext )}.
      */

Modified: directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/interceptor/context/AbstractOperationContext.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/interceptor/context/AbstractOperationContext.java?rev=955056&r1=955055&r2=955056&view=diff
==============================================================================
--- directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/partition/Partition.java (original)
+++ directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/partition/Partition.java Tue Jun 15 21:15:04 2010
@@ -143,26 +143,26 @@ public interface Partition
      * Deletes a leaf entry from this ContextPartition: non-leaf entries cannot be 
      * deleted until this operation has been applied to their children.
      *
      * @param opContext the context of the entry to
      * delete from this ContextPartition.
      * @throws Exception if there are any problems
      */
-    void delete( DeleteOperationContext opContext ) throws LdapException;
+    void delete( DeleteOperationContext deleteContext ) throws LdapException;
 
 
     /**
      * Adds an entry to this ContextPartition.
      *
      * @param opContext the context used  to add and entry to this ContextPartition
      * @throws LdapException if there are any problems
      */
-    void add( AddOperationContext opContext ) throws LdapException;
+    void add( AddOperationContext addContext ) throws LdapException;
 
 
     /**
      * Modifies an entry by adding, removing or replacing a set of attributes.
      *
      * @param opContext The context containing the modification operation 
      * to perform on the entry which is one of constants specified by the 
      * DirContext interface:
      * <code>ADD_ATTRIBUTE, REMOVE_ATTRIBUTE, REPLACE_ATTRIBUTE</code>.
@@ -173,7 +173,7 @@ public interface Partition
      * @see javax.naming.directory.DirContext#REMOVE_ATTRIBUTE
      * @see javax.naming.directory.DirContext#REPLACE_ATTRIBUTE
      */
-    void modify( ModifyOperationContext opContext ) throws LdapException;
+    void modify( ModifyOperationContext modifyContext ) throws LdapException;
 
 
     /**
@@ -182,11 +182,11 @@ public interface Partition
      * used to optimize operations rather than conducting a full search with 
      * retrieval.
      *
      * @param opContext the context containing the distinguished/absolute name for the search/listing
      * @return a NamingEnumeration containing objects of type {@link ServerSearchResult}
      * @throws Exception if there are any problems
      */
-    EntryFilteringCursor list( ListOperationContext opContext ) throws LdapException;
+    EntryFilteringCursor list( ListOperationContext listContext ) throws LdapException;
 
 
     /**
@@ -197,11 +197,11 @@ public interface Partition
      * namespace specific or implementation specific key for the set of LDAP
      * Controls.
      *
      * @param opContext The context containing the information used by the operation
      * @throws Exception if there are any problems
      * @return a NamingEnumeration containing objects of type 
      */
-    EntryFilteringCursor search( SearchOperationContext opContext ) throws LdapException;
+    EntryFilteringCursor search( SearchOperationContext searchContext ) throws LdapException;
 
 
     /**
@@ -222,11 +222,11 @@ public interface Partition
     /**
      * Fast operation to check and see if a particular entry exists.
      *
      * @param opContext The context used to pass informations
      * @return true if the entry exists, false if it does not
      * @throws Exception if there are any problems
      */
-    boolean hasEntry( EntryOperationContext opContext ) throws LdapException;
+    boolean hasEntry( EntryOperationContext hasEntryContext ) throws LdapException;
 
 
     /**
@@ -235,20 +235,20 @@ public interface Partition
      * This makes sense only in certain namespaces like LDAP and will be ignored
      * if it is irrelevant.
      *
      * @param opContext the modify DN context
      * @throws Exception if there are any problems
      */
-    void rename( RenameOperationContext opContext ) throws LdapException;
+    void rename( RenameOperationContext renameContext ) throws LdapException;
 
 
     /**
      * Transplants a child entry, to a position in the namespace under a new
      * parent entry.
      *
      * @param opContext The context containing the DNs to move
      * @throws Exception if there are any problems
      */
-    void move( MoveOperationContext opContext ) throws LdapException;
+    void move( MoveOperationContext moveContext ) throws LdapException;
 
 
     /**
@@ -271,10 +271,10 @@ public interface Partition
      * need not support this operation.  This operation is here to enable those
      * interested in implementing virtual directories with ApacheDS.
      * 
      * @param opContext the bind context, containing all the needed informations to bind
      * @throws LdapException if something goes wrong
      */
-    void bind( BindOperationContext opContext ) throws LdapException;
+    void bind( BindOperationContext bindContext ) throws LdapException;
 
 
     /**
@@ -282,8 +282,8 @@ public interface Partition
      * need not support this operation.  This operation is here to enable those
      * interested in implementing virtual directories with ApacheDS.
      * 
      * @param opContext the context used to unbind
      * @throws Exception if something goes wrong
      */
-    void unbind( UnbindOperationContext opContext ) throws LdapException;
+    void unbind( UnbindOperationContext unbindContext ) throws LdapException;
 }
@@ -143,26 +143,26 @@ public interface Partition
      * deleted until this operation has been applied to their children.
      *
-     * @param opContext the context of the entry to
+     * @param deleteContext the context of the entry to
      * delete from this ContextPartition.
      * @throws Exception if there are any problems
@@ -143,26 +143,26 @@ public interface Partition
      * Adds an entry to this ContextPartition.
      *
-     * @param opContext the context used  to add and entry to this ContextPartition
+     * @param addContext the context used  to add and entry to this ContextPartition
      * @throws LdapException if there are any problems
      */
@@ -143,26 +143,26 @@ public interface Partition
      * Modifies an entry by adding, removing or replacing a set of attributes.
      *
-     * @param opContext The context containing the modification operation 
+     * @param modifyContext The context containing the modification operation 
      * to perform on the entry which is one of constants specified by the 
      * DirContext interface:
@@ -182,11 +182,11 @@ public interface Partition
      * retrieval.
      *
-     * @param opContext the context containing the distinguished/absolute name for the search/listing
+     * @param listContext the context containing the distinguished/absolute name for the search/listing
      * @return a NamingEnumeration containing objects of type {@link ServerSearchResult}
      * @throws Exception if there are any problems
@@ -197,11 +197,11 @@ public interface Partition
      * Controls.
      *
-     * @param opContext The context containing the information used by the operation
+     * @param searchContext The context containing the information used by the operation
      * @throws Exception if there are any problems
      * @return a NamingEnumeration containing objects of type 
@@ -222,11 +222,11 @@ public interface Partition
      * Fast operation to check and see if a particular entry exists.
      *
-     * @param opContext The context used to pass informations
+     * @param hasEntryContext The context used to pass informations
      * @return true if the entry exists, false if it does not
      * @throws Exception if there are any problems
@@ -235,20 +235,20 @@ public interface Partition
      * if it is irrelevant.
      *
-     * @param opContext the modify DN context
+     * @param renameContext the modify DN context
      * @throws Exception if there are any problems
      */
@@ -235,20 +235,20 @@ public interface Partition
      * parent entry.
      *
-     * @param opContext The context containing the DNs to move
+     * @param moveContext The context containing the DNs to move
      * @throws Exception if there are any problems
      */
@@ -271,10 +271,10 @@ public interface Partition
      * interested in implementing virtual directories with ApacheDS.
      * 
-     * @param opContext the bind context, containing all the needed informations to bind
+     * @param bindContext the bind context, containing all the needed informations to bind
      * @throws LdapException if something goes wrong
      */
@@ -282,8 +282,8 @@ public interface Partition
      * interested in implementing virtual directories with ApacheDS.
      * 
-     * @param opContext the context used to unbind
+     * @param unbindContext the context used to unbind
      * @throws Exception if something goes wrong
      */

Modified: directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/partition/PartitionNexus.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/partition/PartitionNexus.java?rev=955056&r1=955055&r2=955056&view=diff
==============================================================================
--- directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/RegistrySynchronizer.java (original)
+++ directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/RegistrySynchronizer.java Tue Jun 15 21:15:04 2010
@@ -75,13 +75,13 @@ public interface RegistrySynchronizer
     /**
      * Applies a set of modification to an entry
      *
      * @param opContext The OperationContext, which contains the entry and the modifications to apply
      * @param targetEntry The modified entry
      * @param cascaded Unused
      * @return True if the modification has been done
      * @throws Exception If the modification failed
      */
-    boolean modify( ModifyOperationContext opContext, Entry targetEntry, boolean cascaded )
+    boolean modify( ModifyOperationContext modifyContext, Entry targetEntry, boolean cascaded )
         throws LdapException;
     
     void moveAndRename( DN oriChildName, DN newParentName, RDN newRn, boolean deleteOldRn, Entry entry,
@@ -75,13 +75,13 @@ public interface RegistrySynchronizer
      * Applies a set of modification to an entry
      *
-     * @param opContext The OperationContext, which contains the entry and the modifications to apply
+     * @param modifyContext The OperationContext, which contains the entry and the modifications to apply
      * @param targetEntry The modified entry
      * @param cascaded Unused